@@ -22,11 +22,11 @@ class LogseqPage:
     """
     PAGE_PROP_REGEX = re.compile(r"(\w[\w_-]*\w:: .+)")
     def __init__(
-            self,
-            content: str,
-            check_parsing=False,
-            verbose=False,
-            ):
+        self,
+        content: str,
+        check_parsing: bool = False,
+        verbose: bool = False,
+        ) -> None:
         self.verbose = verbose
         assert isinstance(content, str), (
             f"content must be of type string, not '{type(content)}'")
@@ -40,7 +40,7 @@ class LogseqPage:
             for li in lines
         ]
 
-        assert lines[0].lstrip().startswith("- ") or ":: " in lines[0] or (len(lines)==1 and not lines[0].strip()), f"First line of document must start with '[ \t]*- ' or contain a page property or the document must be empty"
+        assert lines[0].lstrip().startswith("-") or ":: " in lines[0] or (len(lines)==1 and not lines[0].strip()), f"First line of document must start with '[ \t]*- ' or contain a page property or the document must be empty"
         lines = [l for l in lines if l.strip()]  # remove empty lines
         pageprop = ""  # as string first
         first_block_reached = False
@@ -162,12 +162,12 @@ class LogseqPage:
         return temp
 
     @content.setter
-    def content(self, new: str):
+    def content(self, new: str) -> None:
         raise Exception(
             "Cannot edit page content directly. "
             "You have to edit the blocks individually.")
 
-    def set_property(self, key, value=None):
+    def set_property(self, key: str, value: str = None) -> None:
         """convenience function to harmonize behavior of page and blocks.
         You can edit self.page_properties as a regular dict instead.
         Set None as the value to delete a key.
@@ -180,10 +180,11 @@ class LogseqPage:
             del self.page_properties[key]
 
     def export_to(
-            self,
-            file_path: str,
-            overwrite=False,
-            ) -> None:
+        self,
+        file_path: str,
+        overwrite: bool = False,
+        allow_empty: bool = False,
+        ) -> None:
         """
         export the blocks to file_path
         """
@@ -194,12 +195,13 @@ class LogseqPage:
 
         cont = self.content
 
-        if cont:
-            cont = cont.replace("    ", "\t")
-            with open(file_path, "w") as f:
-                f.write(cont)
-        else:
-            print("No blocks nor page property found, so we won't even create an output file.")
+        cont = cont.replace("    ", "\t")
+
+        if not cont:
+            assert allow_empty, "Can't save an empty file if allow_empty is False"
+
+        with open(file_path, "w") as f:
+            f.write(cont)
 
     def __str__(self) -> str:
         return "\n".join([str(b) for b in self.blocks])
@@ -221,7 +223,7 @@ class LogseqBlock:
             self,
             content: str,
             verbose: bool = False,
-            ):
+            ) -> None:
         """
         Class with the following new attributes:
             indentation_level: in number of spaces, with tab=4
@@ -278,7 +280,7 @@ class LogseqBlock:
         return cont
 
     @content.setter
-    def content(self, new: str):
+    def content(self, new: str) -> str:
         old = self._blockvalues["content"]
         assert isinstance(new, str), "new content must be a string"
         assert new.lstrip().startswith("-") or ":: " in new, "stripped new content must start with '-' or be a property"
@@ -292,7 +294,7 @@ class LogseqBlock:
         return self._get_indentation()
 
     @indentation_level.setter
-    def indentation_level(self, new: int):
+    def indentation_level(self, new: int) -> None:
         # note: we don't compare the new to the old value
         # because this way we make sure that leading spaces are replaced
         # by tabs
@@ -309,7 +311,7 @@ class LogseqBlock:
         return self._get_TODO_state()
 
     @TODO_state.setter
-    def TODO_state(self, new: str):
+    def TODO_state(self, new: str) -> None:
         old = self._get_TODO_state()
         assert old in ["TODO", "DOING", "NOW", "LATER", "DONE", None], (
             f"Invalid old TODO value: {old}")
@@ -335,11 +337,11 @@ class LogseqBlock:
             self._changed = True
 
     @property
-    def properties(self) -> str:
+    def properties(self) -> dict:
         return self._get_properties()
 
     @properties.setter
-    def property_failedsetter(self, *args, **kwargs):
+    def property_failedsetter(self, *args, **kwargs) -> None:
         raise Exception("To modify the properties you must use self.set_property(key, value)")
 
     def _get_properties(self) -> dict:
@@ -369,7 +371,7 @@ class LogseqBlock:
     def set_property(
             self,
             key: str,
-            value=None):
+            value: str = None) -> None:
         """
         set a property to the block.
         if the value is None, the property will be deleted
